Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(630)

Unified Diff: base/android/java/src/org/chromium/content/common/ProcessInitException.java

Issue 141223002: Move the android library loader from content to base (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix final nits Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/android/java/src/org/chromium/content/common/ProcessInitException.java
diff --git a/content/public/android/java/src/org/chromium/content/common/ProcessInitException.java b/base/android/java/src/org/chromium/content/common/ProcessInitException.java
similarity index 51%
rename from content/public/android/java/src/org/chromium/content/common/ProcessInitException.java
rename to base/android/java/src/org/chromium/content/common/ProcessInitException.java
index 0ebbb17ed5f5ac45964cb4e382021681d5252674..33c7a30bdce3b34bcb2375793727760232cca9d0 100644
--- a/content/public/android/java/src/org/chromium/content/common/ProcessInitException.java
+++ b/base/android/java/src/org/chromium/content/common/ProcessInitException.java
@@ -1,26 +1,30 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
package org.chromium.content.common;
+import org.chromium.base.library_loader.LoaderErrors;
+
/**
* The exception that is thrown when the intialization of a process was failed.
+ * TODO(aberent) Remove this once the downstream patch lands, and move this code to base.
+ * In advance of its deletion this has been moved into the base directory structure, to
+ * allow org.chromium.base.library_loader.ProcessInitException to derive from it. This
+ * will go away as soon as the downstream patch lands.
*/
public class ProcessInitException extends Exception {
- private int mErrorCode = 0;
+ private int mErrorCode = LoaderErrors.LOADER_ERROR_NORMAL_COMPLETION;
/**
* @param errorCode The error code could be one from content/public/common/result_codes.h
* or embedder.
*/
public ProcessInitException(int errorCode) {
mErrorCode = errorCode;
}
/**
* @param errorCode The error code could be one from content/public/common/result_codes.h
* or embedder.
* @param throwable The wrapped throwable obj.
*/
public ProcessInitException(int errorCode, Throwable throwable) {
@@ -1,26 +1,30 @@
/**
- * @param errorCode The error code could be one from content/public/common/result_codes.h
- * or embedder.
+ * @param errorCode This will be one of the LoaderErrors error codes.
*/
public ProcessInitException(int errorCode) {
@@ -1,26 +1,30 @@
}
/**
- * @param errorCode The error code could be one from content/public/common/result_codes.h
- * or embedder.
+ * @param errorCode This will be one of the LoaderErrors error codes.
* @param throwable The wrapped throwable obj.
*/

Powered by Google App Engine
This is Rietveld 408576698